#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from typing import Dict, Any

import yaml

from astra_installer.settings.config import ConfigLoader


class AutoinstallConfigLoader(ConfigLoader):
    def __init__(self, preseed: str) -> None:
        super().__init__()
        self.preseed = preseed

    def load(self) -> Dict[str, Any]:
        config = super().load()
        preseed_config = ConfigLoader.load_file(self.preseed)
        config.update({'preseed': preseed_config})
        return config


class IndentDumper(yaml.Dumper):
    def increase_indent(self, flow=False, indentless=False):
        return super(IndentDumper, self).increase_indent(flow, False)


class AutoinstallConfigSaver():
    @staticmethod
    def save(config: Dict[str, Any]) -> None:
        with open('/var/log/astra-installer-preseed.yaml', 'w') as file:
            yaml.dump(config, file, Dumper=IndentDumper, default_flow_style=False)
